package com.novapp.nova_alarm_plugin;


import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.KeyguardManager;
import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.Service;
import android.app.TaskStackBuilder;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.PixelFormat;
import android.media.MediaPlayer;
import android.media.RingtoneManager;
import android.net.Uri;
import android.os.Build;
import android.os.IBinder;
import android.provider.Settings;
import android.util.Log;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.WindowManager;

import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;

import com.novapp.nova_alarm_plugin.utils.ResourceUtils;


public class KeepAliveService extends Service {
    private static final String TAG = "DaemonService";
    public static final int NOTICE_ID = 100;

    @Override
    public void onCreate() {
        super.onCreate();
        Log.d(TAG, "KeepAliveService onCreate");
        try {
            Class<?> mainClass = Class.forName(getPackageName() + ".MainActivity");
            Intent intent = new Intent(this, mainClass);
            NotificationManager manager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            //8.0 以后需要加上channelId 才能正常显示
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                String channelId = "default";
                String channelName = "默认通知";
                manager.createNotificationChannel(new NotificationChannel(channelId, channelName, NotificationManager.IMPORTANCE_HIGH));
            }
            //设置TaskStackBuilder
            TaskStackBuilder stackBuilder = TaskStackBuilder.create(this);
            stackBuilder.addParentStack(mainClass);
            stackBuilder.addNextIntent(intent);
            PendingIntent pendingIntent = stackBuilder.getPendingIntent(0, PendingIntent.FLAG_UPDATE_CURRENT);
            Notification notification = new NotificationCompat.Builder(this, "default")
                    .setSmallIcon(ResourceUtils.getAppLogoId(this))
                    .setContentTitle("标题")
                    .setContentText("这是内容，点击我可以跳转")
                    .setAutoCancel(false)
                    .setOngoing(true)
                    .setDefaults(Notification.DEFAULT_ALL)
                    .setWhen(System.currentTimeMillis())
                    .setContentIntent(pendingIntent)
                    .build();
            manager.notify(1, notification);


        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }


    }

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        if (intent.getExtras() == null) return START_STICKY;
        String title = intent.getExtras().getString("title");
        String content = intent.getExtras().getString("content");
        int notifyId = intent.getExtras().getInt("notifyId");
        Log.d(TAG, "KeepAliveService onCreate");
        try {
             Class<?> mainClass = Class.forName(getPackageName() + ".MainActivity");
            final Intent intentMain = new Intent(this, mainClass);
            NotificationManager manager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            //8.0 以后需要加上channelId 才能正常显示
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                String channelId = "alert";
                String channelName = "重要通知";
                manager.createNotificationChannel(new NotificationChannel(channelId, channelName, NotificationManager.IMPORTANCE_HIGH));
            }
            //设置TaskStackBuilder
            TaskStackBuilder stackBuilder = TaskStackBuilder.create(this);
            stackBuilder.addParentStack(mainClass);
            stackBuilder.addNextIntent(intentMain);
            PendingIntent pendingIntent = stackBuilder.getPendingIntent(0, PendingIntent.FLAG_UPDATE_CURRENT);
            Notification notification = new NotificationCompat.Builder(this, "alert")
                    .setSmallIcon(ResourceUtils.getAppLogoId(this))
                    .setContentTitle(title)
                    .setVisibility(NotificationCompat.VISIBILITY_PUBLIC)
                    .setAutoCancel(false)
                    .setContentText(System.currentTimeMillis() + content)
                    .setDefaults(Notification.DEFAULT_SOUND | Notification.DEFAULT_LIGHTS | Notification.DEFAULT_VIBRATE)
                    .setSound(RingtoneManager.getDefaultUri(RingtoneManager.TYPE_NOTIFICATION))
                    .setWhen(System.currentTimeMillis())
                    .setContentIntent(pendingIntent)
                    .build();
            manager.notify(notifyId, notification);


            final   MediaPlayer  mediaPlayer = MediaPlayer.create(this, RingtoneManager.getDefaultUri(RingtoneManager.TYPE_ALARM));
            mediaPlayer.setLooping(true);
            mediaPlayer.start();

            final  WindowManager  windowManager = (WindowManager)getSystemService(WINDOW_SERVICE);
            LayoutInflater layoutInflater=(LayoutInflater)getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            final View view=layoutInflater.inflate(R.layout.dialog_simple, null);

            view.findViewById(R.id.dialog_confirm).setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    mediaPlayer.stop();
                    windowManager.removeViewImmediate(view);

                }
            });

            WindowManager.LayoutParams params;
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
                params = new WindowManager.LayoutParams(
                        WindowManager.LayoutParams.WRAP_CONTENT,
                        WindowManager.LayoutParams.WRAP_CONTENT,
                        WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY,
                        WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE,
                        PixelFormat.TRANSLUCENT);
            } else {
                params = new WindowManager.LayoutParams(
                        WindowManager.LayoutParams.WRAP_CONTENT,
                        WindowManager.LayoutParams.WRAP_CONTENT,
                        WindowManager.LayoutParams.TYPE_PHONE,
                        WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE,
                        PixelFormat.TRANSLUCENT);
            }
            params.gravity= Gravity.CENTER|Gravity.CENTER;
            params.x=0;
            params.y=0;
            windowManager.addView(view, params);

        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }

        return START_STICKY;
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        // 如果Service被杀死，干掉通知
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
            NotificationManager mManager = (NotificationManager) getSystemService(NOTIFICATION_SERVICE);
            mManager.cancel(NOTICE_ID);
        }
        Log.d(TAG, "DaemonService---->onDestroy，前台service被杀死");
        // 重启自己
        Intent intent = new Intent(getApplicationContext(), KeepAliveService.class);
        startService(intent);
    }
}
