package com.novapp.nova_alarm_plugin;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.app.KeyguardManager;
import android.content.Context;
import android.content.Intent;
import android.media.MediaPlayer;
import android.media.RingtoneManager;
import android.net.Uri;
import android.os.Build;
import android.os.PowerManager;
import android.provider.Settings;
import android.view.LayoutInflater;
import android.view.View;
import android.view.WindowManager;

import androidx.annotation.NonNull;

import com.novapp.nova_alarm_plugin.calendar.CalendarReminderUtils;

import java.io.IOException;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import static android.content.Context.KEYGUARD_SERVICE;
import static com.novapp.nova_alarm_plugin.utils.ClockPluginConstant.*;

/**
 * NovaAlarmPlugin
 */
public class NovaAlarmPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {

    private static Activity appContext;


    private MediaPlayer player = new MediaPlayer();


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        final MethodChannel channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        appContext = registrar.activity();
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "nova_alarm_plugin");
        channel.setMethodCallHandler(new NovaAlarmPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        switch (call.method) {
            case initClockService:
                initClockService();
                result.success(true);
                break;
            case requestCalendarPermission:
                CalendarReminderUtils.checkCalendarPermission(appContext);
                break;
            case insertCalenderEvent:
                CalendarReminderUtils.addCalendarEvent(appContext, call, result);
                break;
            case deleteCalendarEvent:
                CalendarReminderUtils.deleteCalendarEvent(appContext, call, result);
                break;
            case showAndroidNotification:
                startClockNotification(call);
                break;
            default:
                result.notImplemented();
                break;
        }

    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        appContext = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    private void initClockService() {
        appContext.startService(new Intent(appContext, KeepAliveService.class));
    }

    private void startClockNotification(final MethodCall call) {
        String title = call.argument("title");
        String content = call.argument("content");
        int notifyId = call.argument("notifyId");
        Intent intent = new Intent(appContext, KeepAliveService.class);
        intent.putExtra("title", title);
        intent.putExtra("content", content);
        intent.putExtra("notifyId", notifyId);
        appContext.startService(intent);
//        startClockNotification(appContext);

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (!Settings.canDrawOverlays(appContext)) {
                Intent check = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION, Uri.parse("package:" + appContext.getPackageName()));
                appContext.startActivityForResult(check, 0);
            }
        }

    }

    private void startClockNotification(Context appContext) {
        final PowerManager pm = (PowerManager) appContext.getSystemService(Context.POWER_SERVICE);
        @SuppressLint("InvalidWakeLockTag") PowerManager.WakeLock mWakelock = pm.newWakeLock(PowerManager.ACQUIRE_CAUSES_WAKEUP
                | PowerManager.FULL_WAKE_LOCK, "AlertDialog");
        mWakelock.acquire();
        // 屏幕解锁，需要设置权限
        KeyguardManager keyguardManager = (KeyguardManager) appContext.getSystemService(KEYGUARD_SERVICE);
        KeyguardManager.KeyguardLock keyguardLock = keyguardManager
                .newKeyguardLock("AlertDialog");
        keyguardLock.disableKeyguard();
        try {
            Intent intent = new Intent(appContext, ClockAlarmActivity.class);
            appContext.startActivity(intent);
        } catch (IllegalArgumentException localIllegalArgumentException) {
            localIllegalArgumentException.printStackTrace();
        } catch (SecurityException localSecurityException) {
            localSecurityException.printStackTrace();
        } catch (IllegalStateException localIllegalStateException) {
            localIllegalStateException.printStackTrace();
        }


    }
}
